@@ -2,7 +2,8 @@
 #' 
 #' If you're building a package and want a simple set of
 #' Makevars files to export, this function will handle it
-#' for you.
+#' for you. Borrowed from the Rcpp \code{rcpp.package.skeleton}
+#' function.
 #' @param src the location to output the Makevars.
 Rcpp_gen_makevars <- function(src=file.path( getwd(), "src" )) {
   
@@ -20,4 +21,7 @@ Rcpp_gen_makevars <- function(src=file.path( getwd(), "src" )) {
     message(" >> added Makevars.win file with Rcpp settings")
   }
   
-}
\ No newline at end of file
+}
+
+#' @rdname Rcpp_gen_makevars
+rcpp_gen_makevars <- Rcpp_gen_makevars
\ No newline at end of file
